You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:12:03 UTC

svn commit: r1591060 [10/15] - in /openoffice/trunk/main: helpcontent2/source/text/scalc/01/ helpcontent2/source/text/shared/01/ helpcontent2/source/text/simpress/01/ helpcontent2/source/text/smath/01/ helpcontent2/source/text/swriter/01/ helpcontent2/...

Modified: openoffice/trunk/main/mysqlc/source/mysqlc_connection.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/mysqlc/source/mysqlc_connection.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/mysqlc/source/mysqlc_connection.cxx (original)
+++ openoffice/trunk/main/mysqlc/source/mysqlc_connection.cxx Tue Apr 29 19:11:53 2014
@@ -422,7 +422,7 @@ sal_Bool SAL_CALL OConnection::isClosed(
 	OSL_TRACE("OConnection::isClosed");
 	MutexGuard aGuard(m_aMutex);
 
-	// just simple -> we are close when we are disposed taht means someone called dispose(); (XComponent)
+	// just simple -> we are close when we are disposed that means someone called dispose(); (XComponent)
 	return (OConnection_BASE::rBHelper.bDisposed);
 }
 /* }}} */

Modified: openoffice/trunk/main/mysqlc/source/mysqlc_statement.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/mysqlc/source/mysqlc_statement.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/mysqlc/source/mysqlc_statement.cxx (original)
+++ openoffice/trunk/main/mysqlc/source/mysqlc_statement.cxx Tue Apr 29 19:11:53 2014
@@ -419,7 +419,7 @@ void OCommonStatement::setFastPropertyVa
 	throw (Exception)
 {
 	OSL_TRACE("OCommonStatement::setFastPropertyValue_NoBroadcast");
-	// set the value to what ever is nescessary
+	// set the value to what ever is necessary
 	switch (nHandle) {
 		case PROPERTY_ID_QUERYTIMEOUT:
 		case PROPERTY_ID_MAXFIELDSIZE:

Modified: openoffice/trunk/main/mysqlc/source/mysqlc_subcomponent.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/mysqlc/source/mysqlc_subcomponent.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/mysqlc/source/mysqlc_subcomponent.hxx (original)
+++ openoffice/trunk/main/mysqlc/source/mysqlc_subcomponent.hxx Tue Apr 29 19:11:53 2014
@@ -129,7 +129,7 @@ namespace connectivity
 			}
 
 			/** call this in the getInfoHelper method of your derived class. The method returns the array helper of the
-				class, which is created if neccessary.
+				class, which is created if necessary.
 			*/
 			::cppu::IPropertyArrayHelper*	getArrayHelper();
 

Modified: openoffice/trunk/main/o3tl/inc/o3tl/heap_ptr.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/o3tl/inc/o3tl/heap_ptr.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/o3tl/inc/o3tl/heap_ptr.hxx (original)
+++ openoffice/trunk/main/o3tl/inc/o3tl/heap_ptr.hxx Tue Apr 29 19:11:53 2014
@@ -38,7 +38,7 @@ namespace o3tl
     -------------
     heap_ptr<> can be used for class members on the heap.
       - One cannot forget to delete them in the destructor.
-      - Constness will be transfered from the owning instance.
+      - Constness will be transferred from the owning instance.
 
     heap_ptr<> can also be used as smart pointer in function bodies to
     ensure exception safety.

Modified: openoffice/trunk/main/odk/cfgWin.js
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/cfgWin.js?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/cfgWin.js (original)
+++ openoffice/trunk/main/odk/cfgWin.js Tue Apr 29 19:11:53 2014
@@ -918,7 +918,7 @@ function writeBatFile(fdir, file)
 
     newFile.Write(
         "@echo off\n" +
-        "REM This script sets all enviroment variables, which\n" +
+        "REM This script sets all environment variables, which\n" +
         "REM are necessary for building the examples of the Office Development Kit.\n" +
         "REM The Script was developed for the operating systems Windows.\n" +
         "REM The SDK name\n" +

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/EventHandler.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/EventHandler.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/EventHandler.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/EventHandler.java Tue Apr 29 19:11:53 2014
@@ -408,7 +408,7 @@ public class EventHandler
 
 
 
-    /** The proxy that runs in a seperate thread and allows to call back to
+    /** The proxy that runs in a separate thread and allows to call back to
         the Office without running into dead-locks.
     */
     private EventListenerProxy maListenerProxy;

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/EventListenerProxy.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/EventListenerProxy.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/EventListenerProxy.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/EventListenerProxy.java Tue Apr 29 19:11:53 2014
@@ -36,7 +36,7 @@ import java.util.LinkedList;
        objects.
     2. Top window events inform the listener about new or removed windows.
 
-    This class exists because events had to be handled in a seperate thread
+    This class exists because events had to be handled in a separate thread
     to avoid dead locks: The thread that receives an event must no call back
     to the Office directly.  
 
@@ -206,7 +206,7 @@ class EventListenerProxy
 
     /** The queue of event objects, LinkedList<Runnable>.
         The queue object will also serve as lock for the consumer/producer type
-        syncronization.
+        synchronization.
     */
     private LinkedList maEventQueue;
 

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/GraphicalDisplay.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/GraphicalDisplay.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/GraphicalDisplay.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Accessibility/GraphicalDisplay.java Tue Apr 29 19:11:53 2014
@@ -69,7 +69,7 @@ public class GraphicalDisplay
             (int)(mnVOffset+0.5),
             (int)(mnScale*aScreenSize.getWidth()),
             (int)(mnScale*aScreenSize.getHeight()));
-        // Draw a frame arround the screen rectangle to increase its visibility.
+        // Draw a frame around the screen rectangle to increase its visibility.
         g.setColor (Color.BLACK);
         g.drawRect (
             (int)(mnHOffset+0.5),

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java Tue Apr 29 19:11:53 2014
@@ -92,7 +92,7 @@ public class AsyncJob extends    WeakBas
                                           com.sun.star.task.XJobListener  xListener)
         throws com.sun.star.lang.IllegalArgumentException
     {
-        // For asynchronous jobs a valid listener reference is guranteed normaly ...
+        // For asynchronous jobs a valid listener reference is guaranteed normaly ...
         if (xListener == null)
             throw new com.sun.star.lang.IllegalArgumentException("invalid listener");
 
@@ -118,7 +118,7 @@ public class AsyncJob extends    WeakBas
                 lDynamicData = (com.sun.star.beans.NamedValue[])com.sun.star.uno.AnyConverter.toArray(lArgs[i].Value);
         }
 
-        // Analyze the environment info. This sub list is the only guarenteed one!
+        // Analyze the environment info. This sub list is the only guaranteed one!
         if (lEnvironment == null)
             throw new com.sun.star.lang.IllegalArgumentException("no environment");
 
@@ -192,7 +192,7 @@ public class AsyncJob extends    WeakBas
         aSaveRequest.Name  = "SaveArguments";
         aSaveRequest.Value = lJobConfig;
 
-        // Deactivation is usefull inside EXECUTOR environment only
+        // Deactivation is useful inside EXECUTOR environment only
         if (sEnvType.equals("EXECUTOR"))
         {
             ++c;
@@ -201,7 +201,7 @@ public class AsyncJob extends    WeakBas
             aDeactivation.Value = java.lang.Boolean.TRUE;
         }
 
-        // Sending of result events is usefull inside DISPATCH environment only
+        // Sending of result events is useful inside DISPATCH environment only
         if (sEnvType.equals("DISPATCH"))
         {
             ++c;
@@ -286,8 +286,8 @@ public class AsyncJob extends    WeakBas
         }
         catch(java.lang.Throwable exIgnore)
         {
-            // ignore any problem, which can occure here.
-            // It's not realy a bug for this example job, if
+            // ignore any problem, which can occur here.
+            // It's not really a bug for this example job, if
             // it's message could not be printed out!
         }
     }
@@ -297,7 +297,7 @@ public class AsyncJob extends    WeakBas
     private void showInfoNonModal( java.lang.String sTitle   ,
                                    java.lang.String sMessage )
     {
-        // Couldnt be implemented realy using the toolkit ...
+        // Couldnt be implemented really using the toolkit ...
         // Because we need a parent anytime.
         // And showing e.g. a java dialog can make some trouble
         // inside office ... but we have no chance here.

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Components/Thumbs/org/openoffice/comp/test/Thumbs.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Components/Thumbs/org/openoffice/comp/test/Thumbs.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Components/Thumbs/org/openoffice/comp/test/Thumbs.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Components/Thumbs/org/openoffice/comp/test/Thumbs.java Tue Apr 29 19:11:53 2014
@@ -47,7 +47,7 @@ public class Thumbs {
             org.openoffice.test.XImageShrinkFilter xImageShrinkFilter =
                 org.openoffice.test.ImageShrink.create(xRemoteContext);
                 
-            System.out.println("ImageShrink component succesfully instantiated");
+            System.out.println("ImageShrink component successfully instantiated");
 
             java.io.File f = new java.io.File(".");          
             System.out.println("set SourceDrectory ...");              

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/How_to_write_my_own_driver.txt
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/How_to_write_my_own_driver.txt?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/How_to_write_my_own_driver.txt (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/How_to_write_my_own_driver.txt Tue Apr 29 19:11:53 2014
@@ -22,7 +22,7 @@
 How to write my own sdbc driver
 
 Pre implementation steps
-- search all occurances of skeleton and replace them to a name which you prefer
+- search all occurrences of skeleton and replace them to a name which you prefer
 
 1. Implement a class called driver or modify the existing skeleton	-> have a look at SDriver.?xx 
 2. Implement a class called connection					-> have a look at SConnection.?xx 	

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/OSubComponent.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/OSubComponent.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/OSubComponent.hxx (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/OSubComponent.hxx Tue Apr 29 19:11:53 2014
@@ -119,7 +119,7 @@ namespace connectivity
 			}
 
 			/** call this in the getInfoHelper method of your derived class. The method returns the array helper of the
-				class, which is created if neccessary.
+				class, which is created if necessary.
 			*/
 			::cppu::IPropertyArrayHelper*	getArrayHelper();
 

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SConnection.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SConnection.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SConnection.cxx (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SConnection.cxx Tue Apr 29 19:11:53 2014
@@ -207,7 +207,7 @@ sal_Bool SAL_CALL OConnection::isClosed(
 {
 	::osl::MutexGuard aGuard( m_aMutex );
 	
-	// just simple -> we are close when we are disposed taht means someone called dispose(); (XComponent)
+	// just simple -> we are close when we are disposed that means someone called dispose(); (XComponent)
 	return OConnection_BASE::rBHelper.bDisposed;
 }
 // --------------------------------------------------------------------------------

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SResultSet.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SResultSet.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SResultSet.cxx (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SResultSet.cxx Tue Apr 29 19:11:53 2014
@@ -388,7 +388,7 @@ void SAL_CALL OResultSet::beforeFirst(  
 	checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
 		
 	// move before the first row so that isBeforeFirst returns false
-	// the smae for other movement methods
+	// the same for other movement methods
 }
 // -------------------------------------------------------------------------
 void SAL_CALL OResultSet::afterLast(  ) throw(SQLException, RuntimeException)

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SStatement.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SStatement.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SStatement.cxx (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Database/DriverSkeleton/SStatement.cxx Tue Apr 29 19:11:53 2014
@@ -290,7 +290,7 @@ sal_Bool OStatement_Base::convertFastPro
 // -------------------------------------------------------------------------
 void OStatement_Base::setFastPropertyValue_NoBroadcast(sal_Int32 nHandle,const Any& rValue) throw (Exception)
 {
-	// set the value to what ever is nescessary
+	// set the value to what ever is necessary
 	switch(nHandle)
 	{
 		case PROPERTY_ID_QUERYTIMEOUT:

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/DataAwareness.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/DataAwareness.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/DataAwareness.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/DataAwareness.java Tue Apr 29 19:11:53 2014
@@ -208,7 +208,7 @@ public class DataAwareness extends Docum
 	/* ------------------------------------------------------------------ */
     public void resetted( EventObject aEvent ) throws com.sun.star.uno.RuntimeException
 	{
-		// check if this reset occured becase we're on a new record
+		// check if this reset occurred becase we're on a new record
 		XPropertySet xFormProps = UNO.queryPropertySet(  aEvent.Source );
 		try
 		{
@@ -445,7 +445,7 @@ public class DataAwareness extends Docum
 	}
 
 	/* ------------------------------------------------------------------ */
-	/** creates the table witht the given name, using the given statement
+	/** creates the table with the given name, using the given statement
 	*/
 	protected boolean implCreateTable( XConnection xConn, String sCreateStatement, String sTableName ) throws java.lang.Exception
 	{
@@ -844,7 +844,7 @@ public class DataAwareness extends Docum
 		m_aSalesLocker = new ControlLock( xSalesFormProps, "SALENR" );
 		m_aSalesLocker.enableLock( m_bProtectKeyFields );
 
-		// initally, we want to generate keys when moving to a new record
+		// initially, we want to generate keys when moving to a new record
 		xKeyGen.setPropertyValue( "DefaultState", new Short( (short)1 ) );
 
         // --------------------------------------------------------------

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java Tue Apr 29 19:11:53 2014
@@ -28,7 +28,7 @@ import com.sun.star.util.XCloseable;
 
 public abstract class DocumentBasedExample implements com.sun.star.lang.XEventListener
 {
-    /// the intial remote context from the office
+    /// the initial remote context from the office
     protected XComponentContext       m_xCtx;
     /// our current test document
     protected DocumentHelper          m_document;

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/KeyGenerator.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/KeyGenerator.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/KeyGenerator.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/KeyGenerator.java Tue Apr 29 19:11:53 2014
@@ -238,7 +238,7 @@ class KeyGeneratorForReset extends Uniqu
 	/* ------------------------------------------------------------------ */
     public void resetted( com.sun.star.lang.EventObject aEvent ) throws com.sun.star.uno.RuntimeException
 	{
-		// check if this reset occured becase we're on a new record
+		// check if this reset occurred becase we're on a new record
 		XPropertySet xFormProps = UNO.queryPropertySet( aEvent.Source );
 		try
 		{

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/Makefile
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/Makefile?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/Makefile (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/Makefile Tue Apr 29 19:11:53 2014
@@ -162,7 +162,7 @@ FormsExample : $(APP1_JAR)  $(APP2_JAR) 
 	@echo $(MAKE) $(APP3_NAME).run
 	@echo $(MAKE) $(APP4_NAME).run
 	@echo -
-	@echo Note: The data awareness example needs a running data source whith name
+	@echo Note: The data awareness example needs a running data source with name
 	@echo $(SQM)      $(SQM)"$(QM)OO_SDK_Demo_DB$(QM)". Make sure that you have created such a data source,
 	@echo -
 	@echo The document "$(QM)ProgrammaticScriptAssignment.odt$(QM)" demonstrates

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/URLHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/URLHelper.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/URLHelper.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Forms/URLHelper.java Tue Apr 29 19:11:53 2014
@@ -28,7 +28,7 @@ public class URLHelper
 {
     /**
      * Because the office need URLs for loading/saving documents
-     * we must convert used system pathes.
+     * we must convert used system paths.
      * And java use another notation for file URLs ... correct it.
      *
      * @param aSystemPath

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java Tue Apr 29 19:11:53 2014
@@ -31,8 +31,8 @@ import java.io.*;
  *
  * This applet is a sample implementation of the 
  * OpenOffice.org bean. 
- * When initally loaded the applet has two buttons
- * one for opening an existant file and one to open 
+ * When initially loaded the applet has two buttons
+ * one for opening an existent file and one to open 
  * a blank document of a given type supported by
  * OpenOffice.org eg. Writer, Calc, Impress, .....
  *
@@ -84,7 +84,7 @@ public class OOoBeanViewer extends java.
         documentTypePopUp = new javax.swing.JPopupMenu();
         storeDocumentButton = new javax.swing.JButton("store to buffer");
         loadDocumentButton = new javax.swing.JButton("load from buffer");
-        syswinButton = new javax.swing.JButton("release/aquire");
+        syswinButton = new javax.swing.JButton("release/acquire");
 
         menuBarButton = new javax.swing.JCheckBox("MenuBar");
 		menuBarButton.setSelected( aBean.isMenuBarVisible() );

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/ContextMenuInterceptor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/ContextMenuInterceptor.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/ContextMenuInterceptor.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/ContextMenuInterceptor.java Tue Apr 29 19:11:53 2014
@@ -116,7 +116,7 @@ public class ContextMenuInterceptor impl
             }
         }
         catch ( com.sun.star.uno.RuntimeException ex ) {
-            // something strange has happend!
+            // something strange has happened!
             System.out.println( " Sample caught exception! " + ex );
             System.exit(1);
         }
@@ -234,7 +234,7 @@ public class ContextMenuInterceptor impl
             // we used an invalid index for accessing a container
         }
         catch ( com.sun.star.uno.Exception ex ) {
-            // something strange has happend!
+            // something strange has happened!
         }
         catch ( java.lang.Exception ex ) {
             // catch java exceptions and something useful

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java Tue Apr 29 19:11:53 2014
@@ -150,7 +150,7 @@ public class CustomizeView extends    JP
 
         // be frame action listener
         // The callback will update listener connections
-        // for status updates automaticly!
+        // for status updates automatically!
         m_aMenuBarListener   = new StatusListener(m_cbMenuBar  ,MENUBAR_ON  ,MENUBAR_OFF  ,xFrame, FEATUREURL_MENUBAR  );
         m_aToolBarListener   = new StatusListener(m_cbToolBar  ,TOOLBAR_ON  ,TOOLBAR_OFF  ,xFrame, FEATUREURL_TOOLBAR  );
         m_aObjectBarListener = new StatusListener(m_cbObjectBar,OBJECTBAR_ON,OBJECTBAR_OFF,xFrame, FEATUREURL_OBJECTBAR);

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Desk.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Desk.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Desk.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Desk.java Tue Apr 29 19:11:53 2014
@@ -42,7 +42,7 @@ public class Desk
     /**
      * main
      * Establish connection to a remote office and starts the demo application.
-     * User can overwrite some of neccessary start options by using command line parameters.
+     * User can overwrite some of necessary start options by using command line parameters.
      *
      * syntax: Desk [mode={inplace|outplace}] [file=<filename>]
      *
@@ -76,7 +76,7 @@ public class Desk
         // Create first document view.
         // This one will register himself at the global
         // ViewContainer. Further views will be open
-        // automaticly started from this first one.
+        // automatically started from this first one.
         DocumentView aView = new DocumentView();
         aView.setVisible(true);
         aView.createFrame();

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java Tue Apr 29 19:11:53 2014
@@ -37,7 +37,7 @@ import java.awt.event.WindowEvent;
 // __________ Implementation __________
 
 /**
- * This implement a java frame wich contains
+ * This implement a java frame which contains
  * an office document, shows some status informations
  * about that, provides simple functionality on it
  * (e.g. toggle menubar, save document) and
@@ -71,7 +71,7 @@ public class DocumentView extends    JFr
     /**
      * @member  mxFrame             office frame which contains the document of this view
      *
-     * @member  maStatusView        special panel wich show available status informations of currently loaded document
+     * @member  maStatusView        special panel which show available status informations of currently loaded document
      * @member  maDocumentView      use JNI mechanism to plug an office window into our own java UI container (used for inplace mode only!)
      * @member  maCustomizeView     special panel makes it possible to toggle menubar/toolbar or objectbar of loaded document
      * @member  maInterceptor       interceptor thread which intercept "new" menu of office frame to open new frames inside this java application
@@ -163,7 +163,7 @@ public class DocumentView extends    JFr
         if(ViewContainer.mbInplace==true)
         {
             // create view to show opened documents
-            // This special view is neccessary for inplace mode only!
+            // This special view is necessary for inplace mode only!
             maDocumentView = new NativeView();
 
             JSplitPane paSplit = new JSplitPane();
@@ -321,7 +321,7 @@ public class DocumentView extends    JFr
         mbDead=true;
 
         // force these sub view to release her remote
-        // refrences too!
+        // references too!
         maStatusView.shutdown();
         maCustomizeView.shutdown();
 
@@ -334,7 +334,7 @@ public class DocumentView extends    JFr
 
         // close the frame and his document
         // Relaesing of our listener connections for disposing()
-        // will be forced automaticly then. Because the frame
+        // will be forced automatically then. Because the frame
         // will call us back ...
         if (mxFrame!=null)
             FunctionHelper.closeFrame(mxFrame);
@@ -352,8 +352,8 @@ public class DocumentView extends    JFr
 
     /**
      * callback from our internal saved frame
-     * which wish to die. Its not neccessary to remove listener connections
-     * here. Because the broadcaster do it automaticly.
+     * which wish to die. Its not necessary to remove listener connections
+     * here. Because the broadcaster do it automatically.
      * We have to release all references to him only.
      *
      * @param aSource
@@ -411,7 +411,7 @@ public class DocumentView extends    JFr
             if( sCommand.compareTo(COMMAND_EXIT) == 0 )
             {
                 // This will force deleting of this and
-                // all other currently opened views automaticly!
+                // all other currently opened views automatically!
                 System.exit(0);
             }
         }

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/IOnewayLink.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/IOnewayLink.java Tue Apr 29 19:11:53 2014
@@ -45,7 +45,7 @@ public interface IOnewayLink
      * @param nRequest
      *          The two user of this callback can define an unique number,
      *          which identify the type of original interface method. So the called
-     *          interface object can decide, which action will be neccessary.
+     *          interface object can decide, which action will be necessary.
      *
      * @param lParams
      *          If the original method used parameters, they will be coded here in

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Interceptor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Interceptor.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Interceptor.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Interceptor.java Tue Apr 29 19:11:53 2014
@@ -34,9 +34,9 @@ import java.util.Vector;
 /**
  * This class can be used to intercept dispatched URL's
  * on any frame used in this demo application.
- * It intercept all URL's wich try to create a new empty frame.
+ * It intercept all URL's which try to create a new empty frame.
  * (e.g. "private:factory/swriter")
- * Nobody can guarantee that this interception will be realy used -
+ * Nobody can guarantee that this interception will be really used -
  * because another interceptor (registered at a later time then this one!)
  * will be called before this one.
  * Implementation is executed inside a new thread to prevent application
@@ -87,7 +87,7 @@ public class Interceptor implements com.
     /**
      * ctor
      * Initialize the new interceptor. Given frame reference can be used to
-     * register this interceptor on it automaticly later.
+     * register this interceptor on it automatically later.
      *
      * @seealso startListening()
      *
@@ -107,7 +107,7 @@ public class Interceptor implements com.
     //_____________________
 
     /**
-     * start working as frame action listener realy.
+     * start working as frame action listener really.
      * We will be frame action listener here. In case
      * we get a frame action which indicates, that we should
      * update our interception. Because such using of an interecptor
@@ -308,12 +308,12 @@ public class Interceptor implements com.
                 return;
         }
 
-        // deregistration will be done everytime ...
-        // But may it's not neccessary to establish a new registration!
+        // deregistration will be done every time ...
+        // But may it's not necessary to establish a new registration!
         // Don't look for ignoring actions - it was done already inside original frameAction() call!
         boolean bRegister = false;
 
-        // analyze the event and decide which reaction is usefull
+        // analyze the event and decide which reaction is useful
         switch(aEvent.Action.getValue())
         {
             case com.sun.star.frame.FrameAction.COMPONENT_ATTACHED_value   : bRegister = true ; break;
@@ -519,7 +519,7 @@ public class Interceptor implements com.
         if (aURL.Complete.startsWith("private:factory") == true)
         {
             // Create view frame for showing loaded documents on demand.
-            // The visible state is neccessary for JNI functionality to get the HWND and plug office
+            // The visible state is necessary for JNI functionality to get the HWND and plug office
             // inside a java window hierarchy!
             DocumentView aNewView = new DocumentView();
             aNewView.setVisible(true);
@@ -532,7 +532,7 @@ public class Interceptor implements com.
 
     /**
      * Notification of status listener isn't guaranteed (instead of listener on XNotifyingDispatch interface).
-     * So this interceptor doesn't support that realy ...
+     * So this interceptor doesn't support that really ...
      */
     public /*ONEWAY*/ void addStatusListener(/*IN*/ com.sun.star.frame.XStatusListener xListener,/*IN*/ com.sun.star.util.URL aURL)
     {
@@ -563,7 +563,7 @@ public class Interceptor implements com.
 
     /**
      * Implements (optional!) optimization for interceptor mechanism.
-     * Any interceptor which provides this special interface is called automaticly
+     * Any interceptor which provides this special interface is called automatically
      * at registration time on this method. Returned URL's will be used to
      * call this interceptor directly without calling his masters before, IF(!)
      * following rules will be true:
@@ -581,7 +581,7 @@ public class Interceptor implements com.
     /**
      * This class listen on the intercepted frame to free all used ressources on closing.
      * We forget the reference to the frame only here. Deregistration
-     * isn't neccessary here - because this frame dies and wish to forgoten.
+     * isn't necessary here - because this frame dies and wish to forgoten.
      *
      * @param aSource
      *          must be our internal saved frame, on which we listen for frame action events

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java Tue Apr 29 19:11:53 2014
@@ -47,7 +47,7 @@ public class NativeView extends java.awt
 
     /**
      * ctor
-     * Does nothing realy.
+     * Does nothing really.
      * We can use our JNI mechanism for an already visible
      * canvas only. So we overload the method for showing ("setVisible()")
      * and make our intialization there. BUt we try to show an empty clean
@@ -63,8 +63,8 @@ public class NativeView extends java.awt
     // ____________________
 
     /**
-     * Overload this method to make neccessary initializations here.
-     * (e.g. get the window handle and neccessary system informations)
+     * Overload this method to make necessary initializations here.
+     * (e.g. get the window handle and necessary system informations)
      *
      * Why here?
      * Because the handle seams to be available for already visible windows
@@ -82,7 +82,7 @@ public class NativeView extends java.awt
     /**
      * to guarantee right resize handling inside a swing container
      * (e.g. JSplitPane) we must provide some informations about our
-     * prefered/minimum and maximum size.
+     * preferred/minimum and maximum size.
      */
     public Dimension getPreferredSize()
     {
@@ -103,7 +103,7 @@ public class NativeView extends java.awt
 
     /**
      * overload paint routine to show provide against
-     * repaint errors if no office view is realy plugged
+     * repaint errors if no office view is really plugged
      * into this canvas.
      * If handle is present - we shouldn't paint anything further.
      * May the remote window is already plugged. In such case we
@@ -152,7 +152,7 @@ public class NativeView extends java.awt
     // ____________________
 
     /**
-     * for using of the JNI methods it's neccessary to load
+     * for using of the JNI methods it's necessary to load
      * system library which exports it.
      */
     static

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java Tue Apr 29 19:11:53 2014
@@ -78,7 +78,7 @@ public class OfficeConnect
      * ctor
      * We try to open the connection in our ctor ... transparently for user.
      * After it was successfully you will find an internal set member
-     * m_xRemoteContext wich means remote component context of the connected office.
+     * m_xRemoteContext which means remote component context of the connected office.
      * The context can be used to get the remote service manager from the office.
      * We made it private to support singleton pattern of these implementation.
      * see getConnection() for further informations
@@ -106,7 +106,7 @@ public class OfficeConnect
 
     /**
      * create uno components inside remote office process
-     * After connection of these proccess to a running office we have access to
+     * After connection of these process to a running office we have access to
      * remote service manager of it.
      * So we can use it to create all existing services. Use this method to create
      * components by name and get her interface. Casting of it to right target
@@ -114,7 +114,7 @@ public class OfficeConnect
      *
      * @param  aType  describe class type of created service
      *                Returned object can be casted directly to this one.
-     *                Uno query was done by this method automaticly.
+     *                Uno query was done by this method automatically.
      * @param  sServiceSpecifier  name of service which should be created
      * @return  the new created service object
      */

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OnewayExecutor.java Tue Apr 29 19:11:53 2014
@@ -28,7 +28,7 @@ import java.util.Vector;
 /**
  * It's not allowed to call synchronoues back inside an oneway interface call.
  * (see IOnewayLink too). So we start a thread (implemented by this class), which
- * gets all neccessary parameters from the original called object and
+ * gets all necessary parameters from the original called object and
  * call it back later inside his run() method. So the execution of such oneway call
  * will be asynchronous. It works in a generic way and can be used or any type
  * of oneway request. Because the source and the target of this call-link knows,
@@ -73,7 +73,7 @@ class OnewayExecutor extends Thread
 
     /**
      * ctor
-     * It's initialize this thread with all neccessary parameters.
+     * It's initialize this thread with all necessary parameters.
      * It gets the object, which wish to be called back and the type
      * and parameters of the original request.
      *
@@ -81,7 +81,7 @@ class OnewayExecutor extends Thread
      *          The two user of this callback can define an unique number,
      *          which identify the type of original interface method.
      *          So the called interface object can decide, which action will be
-     *          neccessary.
+     *          necessary.
      *
      * @param lParams
      *          If the original method used parameters, they will be coded here in
@@ -110,7 +110,7 @@ class OnewayExecutor extends Thread
     /**
      * implements the thread function
      * Here we call the internal set link object back and
-     * give him all neccessary parameters.
+     * give it all necessary parameters.
      * After that we die by ouerself ...
      */
     public void run()
@@ -128,7 +128,7 @@ class OnewayExecutor extends Thread
 
     /**
      * static helper!
-     * To make convertion of the generic parameter list to the original
+     * To make conversion of the generic parameter list to the original
      * one easier - you can use this helper methods. They know how suchlist
      * must be coded. It's not a must to use it - but you can ...
      */

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java Tue Apr 29 19:11:53 2014
@@ -42,7 +42,7 @@ import java.util.Vector;
  *
  * Further we are frame action listener too.
  * So we can update our status listener connections and
- * internal holded dispatch object automaticly.
+ * internal holded dispatch object automatically.
  *
  * Another reason for such extra class for listening:
  * Most listener callbacks are asynchronoues [oneay] requests.
@@ -64,7 +64,7 @@ class StatusListener implements com.sun.
      * @member m_sTrueText          this text will be shown at the used UI control as description for an enabled status
      * @member m_sFalseText         this text will be shown at the used UI control as description for an disabled status
      * @member m_xDispatch          if we listen for status events, we must hold the dispatch object alive!
-     * @member m_xFrame             reference to the frame, which can provide new dispatch objects if it's neccessary to update it
+     * @member m_xFrame             reference to the frame, which can provide new dispatch objects if it's necessary to update it
      * @member m_aURL               and of course we must be registered for a special URL
      * @member m_bIsActionListener  indicates if we are currently registered as a listener for frame action events or not
      * @member m_bIsStatusListener  indicates if we are currently registered as a listener for status events or not
@@ -85,7 +85,7 @@ class StatusListener implements com.sun.
     /**
      * ctor
      * It initialize an instance of this class only.
-     * We sett all neccessary informations on our internal member - that's it
+     * We sett all necessary informations on our internal member - that's it
      */
     StatusListener( /*IN*/ Component                   rControl   ,
                     /*IN*/ String                      sTrueText  ,
@@ -108,13 +108,13 @@ class StatusListener implements com.sun.
     //_____________________
 
     /**
-     * start working as frame action listener realy.
+     * start working as frame action listener really.
      * In case we get such frame action, it indicates that we should
      * update our internal saved dispatch object on which we listen
-     * for status events. So we can do it automaticly. The outside code
+     * for status events. So we can do it automatically. The outside code
      * mustn't check such things. We can work with one frame,
      * till it die. It doesn't matter if he will be used for different
-     * load/save or any other requests. We will be up to date everytime.
+     * load/save or any other requests. We will be up to date every time.
      */
     public void startListening()
     {
@@ -182,9 +182,9 @@ class StatusListener implements com.sun.
     /**
      * This is the callback method for such frame action events, we listen for.
      * Because it's a oneway method we start a thread as reaction. This thread call
-     * us back and we can do neccessary things there.
-     * But we shouldn't start such action - if it's not realy neccessary.
-     * So we check before, if we are intereested on this event realy.
+     * us back and we can do necessary things there.
+     * But we shouldn't start such action - if it's not really necessary.
+     * So we check before, if we are intereested on this event really.
      *
      * @see impl_frameAction()
      *
@@ -229,7 +229,7 @@ class StatusListener implements com.sun.
      * This is the callback method for the status we listen for an wish to show it
      * on our UI control. Of yourse it's a oneway method ... but we doesn't call back
      * to the office synchronously here. We update our UI only. So we don't leave this
-     * java process. In such case it's not neccessary to use threads to decouple it.
+     * java process. In such case it's not necessary to use threads to decouple it.
      * Do it here and now ...
      *
      * @param aEvent
@@ -243,7 +243,7 @@ class StatusListener implements com.sun.
                 return;
 
             // enable/dsiable th control.
-            // Means: If the feature isn't available currently - we can't show an status realy here.
+            // Means: If the feature isn't available currently - we can't show an status really here.
             // Then we should colorize it gray ...
             m_rControl.setEnabled(aEvent.IsEnabled);
 
@@ -280,7 +280,7 @@ class StatusListener implements com.sun.
 
                     // Detect type of state value
                     // and set it on internal well known UI control
-                    // But do it only, if value realy change.
+                    // But do it only, if value really change.
                     if(aEvent.State instanceof String)
                     {
                         String sState = (String)aEvent.State;
@@ -325,7 +325,7 @@ class StatusListener implements com.sun.
                 return;
         }
         // Don't look for ignoring actions - it was done already inside original frameAction() call!
-        // deregistration as status listener will be done here everytime - but registration only, if neccessary!
+        // deregistration as status listener will be done here every time - but registration only, if necessary!
         boolean bRegister = false;
         switch(aEvent.Action.getValue())
         {
@@ -383,9 +383,9 @@ class StatusListener implements com.sun.
     /**
      * callback for disposing events
      * Our dispatch or frame object inform us about his following dead ...
-     * So we must forget his reference. But it's not neccessary to
+     * So we must forget his reference. But it's not necessary to
      * remove listener connections here. Because the broadcaster
-     * forget us automaticly. The only thing we have to do: release
+     * forget us automatically. The only thing we have to do: release
      * his reference and let him die!
      *
      * @param aEvent

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java Tue Apr 29 19:11:53 2014
@@ -34,10 +34,10 @@ import java.lang.String;
 /**
  * Implement a view to show status informations
  * of currently loaded document of a document view.
- * It use seperate listener threads to get this informations
- * and actualize it automaticly if frame broadcast changes of
+ * It use separate listener threads to get this informations
+ * and actualize it automatically if frame broadcast changes of
  * his contained document.
- * Threads are neccessary to prevent this view against deadlocks.
+ * Threads are necessary to prevent this view against deadlocks.
  * These deadlocks can occure if a listener will be notified
  * by the office in an "oneway" method and try to call back
  * to the office by using a synchronous method.
@@ -202,7 +202,7 @@ public class StatusView extends    JPane
      * And because the environment of the frame can be changed - these
      * listener refresh himself internaly for frame action events too.
      * So we register it as such frame action listener only here.
-     * Rest is done automaticly ...
+     * Rest is done automatically ...
      *
      * @param xFrame
      *          will be used as source of possible status events
@@ -214,7 +214,7 @@ public class StatusView extends    JPane
 
         // create some listener on given frame for available status events
         // Created listener instances will register herself on this frame and
-        // show her received informations automaticly on setted UI controls.
+        // show her received informations automatically on setted UI controls.
         m_aFontListener      = new StatusListener(m_laFontValue     ,FONT_ON     ,FONT_OFF     ,xFrame, FEATUREURL_FONT     );
         m_aSizeListener      = new StatusListener(m_laSizeValue     ,SIZE_ON     ,SIZE_OFF     ,xFrame, FEATUREURL_SIZE     );
         m_aBoldListener      = new StatusListener(m_laBoldValue     ,BOLD_ON     ,BOLD_OFF     ,xFrame, FEATUREURL_BOLD     );

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java Tue Apr 29 19:11:53 2014
@@ -47,7 +47,7 @@ public class ViewContainer extends Threa
 
     /**
      * provides a singleton view container
-     * Neccessary for terminate(9 functionality to be able
+     * Necessary for terminate(9 functionality to be able
      * to call Runtime.runFinilization().
      *
      * @return a reference to the singleton ViewContainer instance
@@ -78,7 +78,7 @@ public class ViewContainer extends Threa
 
     /**
      * This register a new view inside this global container
-     * (if it doesnt already exist).
+     * (if it doesn't already exist).
      *
      * @param   aView       view which whish to be registered inside this container
      */
@@ -119,7 +119,7 @@ public class ViewContainer extends Threa
         }
         // If this view is a registered shutdown listener on this view container
         // too, we must call his interface and forget him as possible listener.
-        // It's neccessary to guarantee his dead ...
+        // It's necessary to guarantee his dead ...
         boolean bShutdownView = false;
         synchronized(mlListener)
         {
@@ -135,7 +135,7 @@ public class ViewContainer extends Threa
         // hook at the runtime class. So our run() method will be called.
         // Teh our view container should be empty - but
         // our listener container can include some references.
-        // These objects wich to be informed then and release e.g. some
+        // These objects which to be informed then and release e.g. some
         // remote references.
         if (nViewCount<1)
         {
@@ -248,7 +248,7 @@ public class ViewContainer extends Threa
      * @member  mlListener          list of all currently registered shutdown listener
      * @member  mbShutdownActive    if this shutdown hook already was started it's not a good idea to
      *                              call System.exit() again for other conditions.
-     *                              We supress it by using this variable!
+     *                              We suppress it by using this variable!
      */
     public  static boolean       mbInplace   = false ;
     private static ViewContainer maSingleton = null  ;

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx Tue Apr 29 19:11:53 2014
@@ -182,7 +182,7 @@ sal_Bool XFlatXml::exporter(
 {
 
     // read source data
-    // we are especialy interested in the output stream
+    // we are especially interested in the output stream
     // since that is where our xml-writer will push the data
     // from it's data-source interface
     OUString aName, sURL;

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/Linguistic/LinguisticExamples.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/Linguistic/LinguisticExamples.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/Linguistic/LinguisticExamples.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/Linguistic/LinguisticExamples.java Tue Apr 29 19:11:53 2014
@@ -346,7 +346,7 @@ public class LinguisticExamples
         public void processLinguServiceEvent( LinguServiceEvent aServiceEvent )
         {   
             //! do here whatever you think needs to be done depending
-            //! on the event recieved (e.g. trigger background spellchecking
+            //! on the event received (e.g. trigger background spellchecking
             //! or hyphenation again.)
                     
             System.out.println("Listener called");

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java Tue Apr 29 19:11:53 2014
@@ -100,13 +100,13 @@ public class OfficeConnect
 
     /**
      * create uno components inside remote office process
-     * After connection of these proccess to a running office we have access to remote service manager of it.
+     * After connection of these process to a running office we have access to remote service manager of it.
      * So we can use it to create all existing services. Use this method to create components by name and
      * get her interface. Casting of it to right target interface is part of your implementation.
      *
      * @param  aType              describe class type of created service
      *                              Returned object can be casted directly to this one.
-     *                              Uno query was done by this method automaticly.
+     *                              Uno query was done by this method automatically.
      * @param  sServiceSpecifier  name of service which should be created
      * @return                    Description of the Returned Value
      */

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/ProfUNO/CppBinding/office_connect.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/ProfUNO/CppBinding/office_connect.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/ProfUNO/CppBinding/office_connect.cxx (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/ProfUNO/CppBinding/office_connect.cxx Tue Apr 29 19:11:53 2014
@@ -81,7 +81,7 @@ SAL_IMPLEMENT_MAIN()
             return 1;
         }
 
-        printf( "Connected sucessfully to the office\n" );
+        printf( "Connected successfully to the office\n" );
 	}	
 	catch( Exception &e )
 	{

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/Text/TextDocuments.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/Text/TextDocuments.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/Text/TextDocuments.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/Text/TextDocuments.java Tue Apr 29 19:11:53 2014
@@ -340,7 +340,7 @@ public class TextDocuments {
         mxDocFactory = (XMultiServiceFactory) UnoRuntime.queryInterface(
             XMultiServiceFactory.class, mxDoc );
         
-        // Examples of text fields, dependant text fields and field masters
+        // Examples of text fields, dependent text fields and field masters
         TextFieldExample ();
         
         // Example of using an XEnumerationAccess to iterate over paragraphs and
@@ -530,11 +530,11 @@ public class TextDocuments {
     {
         try
         {
-            // Get a text range refering to the beginning of the text document
+            // Get a text range referring to the beginning of the text document
             XTextRange xStart = mxDocText.getStart();
             // use setString to insert text at the beginning
             xStart.setString ( "This is text inserted at the beginning.\n\n" );
-            // Get a text range refering to the end of the text document
+            // Get a text range referring to the end of the text document
             XTextRange xEnd = mxDocText.getEnd();
             // use setString to insert text at the end
             xEnd.setString ( "This is text inserted at the end.\n\n" );
@@ -694,7 +694,7 @@ public class TextDocuments {
         return ( ( maRandom.nextInt() % 1000 ) * maRandom.nextDouble () );
     }
     
-    /** This method sets the text colour of the cell refered to by sCellName to
+    /** This method sets the text colour of the cell referred to by sCellName to
         white and inserts the string sText in it
      */
     protected static void insertIntoCell(String sCellName, String sText,
@@ -948,14 +948,14 @@ public class TextDocuments {
                     // Make sure that the autotext group contains at least one block
                     if ( aBlockNames.length > 0 )
                     {
-                        // Split the current cell vertically into two seperate cells
+                        // Split the current cell vertically into two separate cells
                         xTableCursor.splitRange ( (short) 1, false );
                         
                         // Put the cursor in the newly created right hand cell 
                         // and select it
                         xTableCursor.goRight ( (short) 1, false );
                         
-                        // Split this cell horizontally to make a seperate cell 
+                        // Split this cell horizontally to make a separate cell 
                         // for each Autotext block
                         if ( ( aBlockNames.length -1 ) > 0 )
                             xTableCursor.splitRange ( 
@@ -1726,7 +1726,7 @@ public class TextDocuments {
             XNamed xSectionNamed = (XNamed) UnoRuntime.queryInterface(XNamed.class,
                       mxDocFactory.createInstance("com.sun.star.text.TextSection"));
             
-            // Set the name of our new section (appropiately) to 'Fish'
+            // Set the name of our new section (appropriately) to 'Fish'
             xSectionNamed.setName ( "Fish" );
 
             // Create the TextColumns service and get it's XTextColumns interface

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/UCB/ResourceManager.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/UCB/ResourceManager.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/examples.html (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/examples.html Tue Apr 29 19:11:53 2014
@@ -2306,7 +2306,7 @@ form controls.</a></td>
  title="link to Forms/DataAwareness.java">DataAwareness</a></td>
                   <td class="cell80">This class implements the basic
 example for a form working on a database. Two tables will be created
-and a form (writer document) with a bussiness example will fill its
+and a form (writer document) with a business example will fill its
 fields from these tables.</td>
                 </tr>
                 <tr>

Modified: openoffice/trunk/main/odk/examples/cpp/complextoolbarcontrols/Makefile
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/cpp/complextoolbarcontrols/Makefile?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/cpp/complextoolbarcontrols/Makefile (original)
+++ openoffice/trunk/main/odk/examples/cpp/complextoolbarcontrols/Makefile Tue Apr 29 19:11:53 2014
@@ -145,7 +145,7 @@ endif
 
 Example : $(COMP_REGISTERFLAG)
 	@echo --------------------------------------------------------------------------------
-	@echo The "$(QM)Complext Toolbar Controlls$(QM)" component was installed if SDK_AUTO_DEPLOYMENT = YES.
+	@echo The "$(QM)Complext Toolbar Controls$(QM)" component was installed if SDK_AUTO_DEPLOYMENT = YES.
 	@echo You can use this component inside your office installation, see the example
 	@echo description.
 	@echo --------------------------------------------------------------------------------

Modified: openoffice/trunk/main/odk/examples/cpp/complextoolbarcontrols/MyProtocolHandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/cpp/complextoolbarcontrols/MyProtocolHandler.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/cpp/complextoolbarcontrols/MyProtocolHandler.cxx (original)
+++ openoffice/trunk/main/odk/examples/cpp/complextoolbarcontrols/MyProtocolHandler.cxx Tue Apr 29 19:11:53 2014
@@ -220,7 +220,7 @@ Sequence< ::rtl::OUString > SAL_CALL MyP
 
 void SAL_CALL BaseDispatch::dispatch( const URL& aURL, const Sequence < PropertyValue >& lArgs ) throw (RuntimeException)
 {
-	/* Its neccessary to hold this object alive, till this method finish.
+	/* Its necessary to hold this object alive, till this method finish.
 	   May the outside dispatch cache (implemented by the menu/toolbar!)
 	   forget this instance during de-/activation of frames (focus!).
 

Modified: openoffice/trunk/main/odk/examples/java/DocumentHandling/DocumentLoader.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/java/DocumentHandling/DocumentLoader.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/java/DocumentHandling/DocumentLoader.java (original)
+++ openoffice/trunk/main/odk/examples/java/DocumentHandling/DocumentLoader.java Tue Apr 29 19:11:53 2014
@@ -64,7 +64,7 @@ public class DocumentLoader {
                 sUrl = sbTmp.toString();
             }    
       
-            // Load a Writer document, which will be automaticly displayed
+            // Load a Writer document, which will be automatically displayed
             com.sun.star.lang.XComponent xComp = xCompLoader.loadComponentFromURL(
                 sUrl, "_blank", 0, new com.sun.star.beans.PropertyValue[0]);
 

Modified: openoffice/trunk/main/odk/examples/java/DocumentHandling/DocumentPrinter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/java/DocumentHandling/DocumentPrinter.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/java/DocumentHandling/DocumentPrinter.java (original)
+++ openoffice/trunk/main/odk/examples/java/DocumentHandling/DocumentPrinter.java Tue Apr 29 19:11:53 2014
@@ -58,7 +58,7 @@ public class DocumentPrinter {
             StringBuffer sUrl = new StringBuffer("file:///");
             sUrl.append(sourceFile.getCanonicalPath().replace('\\', '/'));
       
-            // Load a Writer document, which will be automaticly displayed
+            // Load a Writer document, which will be automatically displayed
             com.sun.star.lang.XComponent xComp = xCompLoader.loadComponentFromURL(
                 sUrl.toString(), "_blank", 0,
                 new com.sun.star.beans.PropertyValue[0] );

Modified: openoffice/trunk/main/odk/examples/java/EmbedDocument/Container1/EmbedContApp.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/java/EmbedDocument/Container1/EmbedContApp.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/java/EmbedDocument/Container1/EmbedContApp.java (original)
+++ openoffice/trunk/main/odk/examples/java/EmbedDocument/Container1/EmbedContApp.java Tue Apr 29 19:11:53 2014
@@ -381,7 +381,7 @@ public class EmbedContApp extends Applet
 		
 		public void actionPerformed( ActionEvent e )
 		{
-			// if has persistance store there
+			// if has persistence store there
 			// if not open SaveAs dialog and store
 			if ( m_xStorage != null && m_xEmbedObj != null )
 			{
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java Tue Apr 29 19:11:53 2014
@@ -110,7 +110,7 @@ public class FunctionHelper
         {
             // "createInstance()" method of used service manager can throw it.
             // Then it wasn't possible to get the URL transformer.
             // Return default instead of realy parsed URL.
             aURL = null;
         }
 
@@ -246,7 +246,7 @@ public class FunctionHelper
             // is returned. But normaly nobody outside the office knows this id.
             // New version of this method ignore the id parameter and creation will
             // work.
             // Note: You must be shure if your window handle can be realy used by
             // the remote office. Means if this java client and the remote office
             // use the same display!
             com.sun.star.awt.XSystemChildFactory xChildFactory =
@@ -300,8 +300,8 @@ public class FunctionHelper
                 // the systemw window handle. A possible reason can be an invisible
                 // java window. In this case it should be enough to set return
                 // values to null. All other ressources (which was created before)
-                // will be freed automaticly if scope wil be leaved.
-                System.out.println("May be the NativeView object wasn't realy visible at calling time of getNativeWindow()?");
+                // will be freed automatically if scope wil be leaved.
+                System.out.println("May be the NativeView object wasn't really visible at calling time of getNativeWindow()?");
                 xPeer   = null;
                 xWindow = null;
             }
@@ -357,7 +357,7 @@ public class FunctionHelper
             com.sun.star.awt.XWindow xWindow = impl_createWindow(xCtx, aParentView);
 
             // pass the window the frame as his new container window.
-            // It's neccessary to do it first  - before you call anything else there.
+            // It's necessary to do it first  - before you call anything else there.
             // Otherwhise the frame throws some exceptions for "uninitialized state".
             xFrame.initialize( xWindow );
 
@@ -382,11 +382,11 @@ public class FunctionHelper
             if(xFrame!=null)
             {
                 // Try to dispose the frame. He should deregister himself at the desktop object
-                // and free all internal used ressources (e.g. the container window) automaticly.
+                // and free all internal used ressources (e.g. the container window) automatically.
                 // It's possible to do that here - because frame has no component inside yet.
                 // So nobody can disagree with that.
                 // After the dispose() call forget all references to this frame and let him die.
-                // If a new exception will occure ... no generell solution exist then.
+                // If a new exception will occur ... no generell solution exist then.
                 // Nobody can guarantee if next call will work or not.
                 com.sun.star.lang.XComponent xComponent = (com.sun.star.lang.XComponent)UnoRuntime.queryInterface(
                     com.sun.star.lang.XComponent.class,
@@ -399,7 +399,7 @@ public class FunctionHelper
         catch(com.sun.star.uno.Exception exUno)
         {
             // "createInstance()" method of used service manager can throw it.
-            // If it occured during creation of desktop service the frame already was created.
+            // If it occurred during creation of desktop service the frame already was created.
             // Free it by decresing his refcount. Changes on the desktop tree couldn't exist.
             // Without the desktop service that wasn't possible. So no further rollbacks must follow.
             if(xFrame!=null)
@@ -421,16 +421,16 @@ public class FunctionHelper
     /**
      * Dispatch an URL to given frame.
      * Caller can register himself for following status events for dispatched
-     * URL too. But nobody guarantee that such notifications will occure.
+     * URL too. But nobody guarantee that such notifications will occur.
      * (see dispatchWithNotification() if you interest on that)
      * The returned dispatch object should be hold alive by caller
      * till he deosn't need it any longer. Otherwise the dispatcher can(!)
      * die by decreasing his refcount.
      *
-     * @param   xFrame      frame wich should be the target of this dispatch
+     * @param   xFrame      frame which should be the target of this dispatch
      * @param   aURL        full parsed and converted office URL for dispatch
      * @param   lProperties optional arguments for dispatch
-     * @param   xListener   optional listener which is registered automaticly for status events
+     * @param   xListener   optional listener which is registered automatically for status events
      *                      (Note: Deregistration is part of this listener himself!)
      *
      * @return  [XDispatch] It's the used dispatch object and can be used for deregistration of an optional listener.
@@ -487,14 +487,14 @@ public class FunctionHelper
      * Dispatch an URL to given frame.
      * Caller can register himself for following result events for dispatched
      * URL too. Notifications are guaranteed (instead of dispatch())
-     * Returning of the dispatch object isn't neccessary.
+     * Returning of the dispatch object isn't necessary.
      * Nobody must hold it alive longer the dispatch needs.
      *
-     * @param   xFrame      frame wich should be the target of this dispatch
+     * @param   xFrame      frame which should be the target of this dispatch
      * @param   aURL        full parsed and converted office URL for dispatch
      * @param   lProperties optional arguments for dispatch
-     * @param   xListener   optional listener which is registered automaticly for status events
-     *                      (Note: Deregistration is not supported. Dispatcher does it automaticly.)
+     * @param   xListener   optional listener which is registered automatically for status events
+     *                      (Note: Deregistration is not supported. Dispatcher does it automatically.)
      */
     public static void executeWithNotification(com.sun.star.frame.XFrame                  xFrame     ,
                                                com.sun.star.util.URL                      aURL       ,
@@ -535,7 +535,7 @@ public class FunctionHelper
      * The result of this operation will be the loaded document for success
      * or null if loading failed.
      *
-     * @param   xFrame          frame wich should be the target of this load call
+     * @param   xFrame          frame which should be the target of this load call
      * @param   sURL            unparsed URL for loading
      * @param   lProperties     optional arguments
      *
@@ -554,7 +554,7 @@ public class FunctionHelper
                 OfficeConnect.getOfficeContext();
 
             // First prepare frame for loading
-            // We must adress it inside the frame tree without any complications.
+            // We must address it inside the frame tree without any complications.
             // So we set an unambigous (we hope it) name and use it later.
             // Don't forget to reset original name after that.
                    sOldName = xFrame.getName();
@@ -674,7 +674,7 @@ public class FunctionHelper
      * It try to export given document in HTML format.
      * Current document will be converted to HTML and moved to new place on disk.
      * A "new" file will be created by given URL (may be overwritten
-     * if it already exist). Right filter will be used automaticly if factory of
+     * if it already exist). Right filter will be used automatically if factory of
      * this document support it. If no valid filter can be found for export,
      * nothing will be done here.
      *
@@ -688,7 +688,7 @@ public class FunctionHelper
         {
             // First detect factory of this document.
             // Ask for the supported service name of this document.
-            // If information is available it can be used to find out wich
+            // If information is available it can be used to find out which
             // filter exist for HTML export. Normaly this filter should be searched
             // inside the filter configuration but this little demo doesn't do so.
             // (see service com.sun.star.document.FilterFactory for further
@@ -735,7 +735,7 @@ public class FunctionHelper
                 {
                     // Export can be forced by saving the document and using a
                     // special filter name which can write needed format. Build
-                    // neccessary argument list now.
+                    // necessary argument list now.
                     // Use special flag "Overwrite" too, to prevent operation
                     // against possible exceptions, if file already exist.
                     com.sun.star.beans.PropertyValue[] lProperties =
@@ -980,7 +980,7 @@ public class FunctionHelper
     /**
      * helper to get a file URL selected by user
      * This method doesn't show any API concepts ...
-     * but is neccessary rof this demo application.
+     * but is necessary rof this demo application.
      *
      * @param   aParent parent window of this dialog
      * @param   bOpen   If it is set to true =>
@@ -110,7 +110,7 @@ public class FunctionHelper
             // "createInstance()" method of used service manager can throw it.
             // Then it wasn't possible to get the URL transformer.
-            // Return default instead of realy parsed URL.
+            // Return default instead of really parsed URL.
             aURL = null;
         }
@@ -246,7 +246,7 @@ public class FunctionHelper
             // New version of this method ignore the id parameter and creation will
             // work.
-            // Note: You must be shure if your window handle can be realy used by
+            // Note: You must be shure if your window handle can be really used by
             // the remote office. Means if this java client and the remote office
             // use the same display!

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/IOnewayLink.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/IOnewayLink.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java Tue Apr 29 19:11:53 2014
@@ -54,7 +54,7 @@ import com.sun.star.lang.IllegalArgument
                 During import/export special functionality can be used to
                 e.g. to change some characters inside the file content
                 or replace some strings (no using of regular expressions!).
-                User can decide at runtime which functionality realy should
+                User can decide at runtime which functionality really should
                 be used by selecting it in an extra filter property dialog.
 
                 So we show how a filter works fro iport/export, use or create
@@ -107,7 +107,7 @@ public class AsciiReplaceFilter
         // native interface
        /**
         * special debug helper to get an idea how expensive
         * the implemented filter operations are realy.
         * May be usefully for own purposes.
         *
         * To see the output inside an office environment
@@ -160,7 +160,7 @@ public class AsciiReplaceFilter
         /**
         * used for initializing after creation
         * If an instance of this service is created by UNO we will be called
-        * automaticly after that to get optional parameters of this creation call.
+        * automatically after that to get optional parameters of this creation call.
         * E.g.: The service com.sun.star.document.FilterFactory use such mechanism
         * to pass our own configuration data to this instance.
         *
@@ -363,7 +363,7 @@ public class AsciiReplaceFilter
 
         /**
         * Makes the filter process breakable. To do so the outside code may use threads.
-        * We use a internal "condition" variable wich is queried by the real filter method on
+        * We use a internal "condition" variable which is queried by the real filter method on
         * every loop they do. So it's more a polling mechanism.
         */
         public void cancel()
@@ -404,7 +404,7 @@ public class AsciiReplaceFilter
          *          the target text model to put the data in
          *
          * @param aOptions
-         *          capsulate all other neccessary informations for this filter request
+         *          capsulate all other necessary informations for this filter request
          *          (streams, replace values ...)
          *
          * @return a bool value which describes if method was successfully or not.
@@ -536,7 +536,7 @@ public class AsciiReplaceFilter
          *          the source text model to get the data from
          *
          * @param aOptions
-         *          capsulate all other neccessary informations for this filter request
+         *          capsulate all other necessary informations for this filter request
          *          (streams, replace values ...)
          *
          * @return a bool value which describes if method was successfully or not.
@@ -561,7 +561,7 @@ public class AsciiReplaceFilter
     
                 measure("get text from model");
     
                 // Normaly this function isn't realy cancelable
                 // But we following operation can be very expensive. So
                 // this place is the last one to stop it.
                 synchronized(this)
@@ -107,7 +107,7 @@ public class AsciiReplaceFilter
        /**
         * special debug helper to get an idea how expensive
-        * the implemented filter operations are realy.
+        * the implemented filter operations are really.
         * May be usefully for own purposes.
         *
@@ -561,7 +561,7 @@ public class AsciiReplaceFilter
                 measure("get text from model");
     
-                // Normaly this function isn't realy cancelable
+                // Normaly this function isn't really cancelable
                 // But we following operation can be very expensive. So
                 // this place is the last one to stop it.

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java Tue Apr 29 19:11:53 2014
@@ -37,8 +37,8 @@ import com.sun.star.ucb.CommandAbortedEx
 import com.sun.star.lang.IllegalArgumentException;
 
 /*-************************************************************************
-  @title        helper to analyze neccessary option properties of our filter
-  @description  Our filter needs some neccessary properties for working:
+  @title        helper to analyze necessary option properties of our filter
+  @description  Our filter needs some necessary properties for working:
                     - a stream for input or output
                     - or an URL for creating such streams
                     - informations about required action on filtering
@@ -160,15 +160,15 @@ public class FilterOptions
             {
                 // ONE argument has the wrong type
                 // But I think we mustn't react here - because we setted
                 // default values for every neccessary item we need.
                 // In case this exception occures - this default exist
                 // and we can live with it.
             }
         }
 
         // Decide if it's neccessary AND possible to open streams.
         // Outside user can check for valid FilterOptions by using
         // corresponding method isValid(). So it's not neccessary to
         // handle this error here in any case.
         if (m_xInput==null && m_xOutput==null && m_sURL!=null)
             impl_openStreams(bImport);
@@ -176,8 +176,8 @@ public class FilterOptions
 
     /**
      * with this method it's possible for the outside filter to decide
      * if he can use this FilterOptions realy or not.
      * That means especialy if neccessary streams are available or not.
      */
     public boolean isValid()
     {
@@ -160,15 +160,15 @@ public class FilterOptions
                 // ONE argument has the wrong type
                 // But I think we mustn't react here - because we setted
-                // default values for every neccessary item we need.
+                // default values for every necessary item we need.
                 // In case this exception occures - this default exist
                 // and we can live with it.
@@ -160,15 +160,15 @@ public class FilterOptions
         }
 
-        // Decide if it's neccessary AND possible to open streams.
+        // Decide if it's necessary AND possible to open streams.
         // Outside user can check for valid FilterOptions by using
@@ -160,15 +160,15 @@ public class FilterOptions
         // Outside user can check for valid FilterOptions by using
-        // corresponding method isValid(). So it's not neccessary to
+        // corresponding method isValid(). So it's not necessary to
         // handle this error here in any case.
         if (m_xInput==null && m_xOutput==null && m_sURL!=null)
@@ -176,8 +176,8 @@ public class FilterOptions
     /**
      * with this method it's possible for the outside filter to decide
-     * if he can use this FilterOptions realy or not.
-     * That means especialy if neccessary streams are available or not.
+     * if he can use this FilterOptions really or not.
+     * That means especially if necessary streams are available or not.
      */
     public boolean isValid()

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/odk/examples/DevelopersGuide/UCB/ResourceManager.java (original)
+++ openoffice/trunk/main/odk/examples/DevelopersGuide/UCB/ResourceManager.java Tue Apr 29 19:11:53 2014
@@ -74,7 +74,7 @@ public class ResourceManager {
      *  This method requires the main and the optional arguments to be set in order to work.
      *  See Constructor.
      *
-     *@return boolean  Returns true if resource successfully transfered, false otherwise
+     *@return boolean  Returns true if resource successfully transferred, false otherwise
      *@exception  com.sun.star.ucb.CommandAbortedException
      *@exception  com.sun.star.uno.Exception
      */
@@ -92,8 +92,8 @@ public class ResourceManager {
      *
      *@param  String   Source URL
      *@param  String   Target folder URL
      *@param  String   Transfering operation (copy, move, link)
      *@return boolean  Returns true if resource successfully transfered, false otherwise
      *@exception  com.sun.star.ucb.CommandAbortedException
      *@exception  com.sun.star.uno.Exception
      */
@@ -164,9 +164,9 @@ public class ResourceManager {
     }
 
     /**
-     * Get new title for the resource to be transfered.
+     * Get new title for the resource to be transferred.
      *
-     *@return String    That contains a new title for the transfered
+     *@return String    That contains a new title for the transferred
      *                  resource. Can be empty. In this case resource
      *                  will keep the title it has in the source folder.
      */
@@ -258,7 +258,7 @@ public class ResourceManager {
             if ( result )
                 System.out.println( "\nTransfering resource succeeded." );
             else
-                System.out.println( "Transfering resource failed." );
+                System.out.println( "Transferring resource failed." );
 
             System.out.println( "   Source URL        : " + sourceURL );
             System.out.println( "   Target Folder URL : " + targetFolderURL );
@@ -92,8 +92,8 @@ public class ResourceManager {
      *@param  String   Source URL
      *@param  String   Target folder URL
-     *@param  String   Transfering operation (copy, move, link)
-     *@return boolean  Returns true if resource successfully transfered, false otherwise
+     *@param  String   Transferring operation (copy, move, link)
+     *@return boolean  Returns true if resource successfully transferred, false otherwise
      *@exception  com.sun.star.ucb.CommandAbortedException
      *@exception  com.sun.star.uno.Exception

Modified: openoffice/trunk/main/odk/examples/DevelopersGuide/examples.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/odk/examples/DevelopersGuide/examples.html?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================